sqltriples.Adapters.PgSQLAdapter

Package sqltriples :: Module Adapters :: Class PgSQLAdapter |
[show private | hide private]
[frames | no frames]

## Class PgSQLAdapter

    Adapter --+
              |
             PgSQLAdapter

Method Summary
| `delete_sequence(self, cursor, sequence_name)`
| `init_sequence(self, cursor, sequence_name)`
Inherited from Adapter
| ``__init__`(self, connection)`
| ``delete_index`(self, cursor, table_name)`
| ``delete_table`(self, cursor, table_name)`
| ``init_index`(self, cursor, table_name)`
| ``init_table`(self, cursor, table_name)`
| ``query_next_bnode_id`(self, cursor, sequence_name)`

Class Variable Summary
`str` | `paramstyle` = `'pyformat'`
`int` | `supports_in_tuples` = 1

Class Variable Details

    ### paramstyle Type: `str` Value:
        'pyformat'

    ### supports_in_tuples Type: `int` Value:
        1

Generated by Epydoc 2.1 on Sat Sep 30 00:54:37 2006 | http://epydoc.sf.net